import { SvelteComponent } from "svelte";
import { DefinitionWalker, type Definition, type StepsConfiguration, type ToolboxConfiguration, type UndoStack, type ValidatorConfiguration, type UidGenerator, type DesignerExtension, type CustomActionHandler, type StepEditorProvider, type RootEditorProvider, type KeyboardConfiguration, type I18n, type PreferenceStorage } from 'sequential-workflow-designer';
declare const __propDef: {
    props: {
        definition: Definition;
        steps: StepsConfiguration;
        toolbox?: false | Omit<ToolboxConfiguration, "isCollapsed"> | undefined;
        isToolboxCollapsed?: boolean | undefined;
        controlBar?: boolean | undefined;
        theme?: string | undefined;
        contextMenu?: boolean | undefined;
        keyboard?: boolean | KeyboardConfiguration | undefined;
        preferenceStorage?: PreferenceStorage | undefined;
        undoStackSize?: number | undefined;
        undoStack?: UndoStack | undefined;
        validator?: ValidatorConfiguration | undefined;
        definitionWalker?: DefinitionWalker | undefined;
        extensions?: DesignerExtension[] | undefined;
        i18n?: I18n | undefined;
        uidGenerator?: UidGenerator | undefined;
        customActionHandler?: CustomActionHandler | undefined;
        /**
             * @description Svelte component that will be used to render the step editor. If this property is set, the `nativeStepEditor` property will be ignored.
             */ stepEditor?: ConstructorOfATypedSvelteComponent | null | undefined;
        /**
             * @description Function that will be used to render the step editor.
             */ nativeStepEditor?: StepEditorProvider | null | undefined;
        /**
             * @description Svelte component that will be used to render the root editor. If this property is set, the `nativeRootEditor` property will be ignored.
             */ rootEditor?: ConstructorOfATypedSvelteComponent | null | undefined;
        /**
             * @description Function that will be used to render the root editor.
             */ nativeRootEditor?: RootEditorProvider | null | undefined;
        isEditorCollapsed?: boolean | undefined;
        isReadonly?: boolean | undefined;
        selectedStepId?: string | null | undefined;
    };
    events: {
        definitionChanged: CustomEvent<{
            definition: Definition;
            isValid: boolean;
        }>;
        selectedStepIdChanged: CustomEvent<{
            stepId: string | null;
        }>;
        isToolboxCollapsedChanged: CustomEvent<{
            isCollapsed: boolean;
        }>;
        isEditorCollapsedChanged: CustomEvent<{
            isCollapsed: boolean;
        }>;
    } & {
        [evt: string]: CustomEvent<any>;
    };
    slots: {};
};
export type SequentialWorkflowDesignerProps = typeof __propDef.props;
export type SequentialWorkflowDesignerEvents = typeof __propDef.events;
export type SequentialWorkflowDesignerSlots = typeof __propDef.slots;
export default class SequentialWorkflowDesigner extends SvelteComponent<SequentialWorkflowDesignerProps, SequentialWorkflowDesignerEvents, SequentialWorkflowDesignerSlots> {
}
export {};
